Simple Pie

<div> <div class="chart-wrap"> <div id="chart"> <ReactApexChart options={this.state.options} series={this.state.series} type="donut" width={380} /> </div> </div> <div class="actions"> <button onClick={() => this.appendData()} > + ADD </button> &nbsp; <button onClick={() => this.removeData()} > - REMOVE </button> &nbsp; <button onClick={() => this.randomize()} > RANDOMIZE </button> &nbsp; <button onClick={() => this.reset()} > RESET </button> </div> </div>